require_relative 'util.rb'

require 'fileutils'

# Handles anything pertaining to the video file repository.
class Repository

  def initialize(path)
    @base_path = path

    # create repository base directory
    create_directory(@base_path)

    # create sub-directories
    sub_paths = ['ingest', 'archive', 'output']
    sub_paths.each { |p|
      create_directory(File.join(@base_path, p))
    }
  end

  def search_ingest
    # create our ingest directory path
    ingest_path = File.join(@base_path, 'ingest')
    # search for files in ingest; ignore non-files (e.g. directories)
    ingest_files = Dir.entries(ingest_path).select { |f| File.file? File.join(ingest_path, f) }

    return ingest_files
  end

  def archive_file(filename)
    # create source and destination paths for the copy
    ingest_path = File.join(@base_path, 'ingest', filename)
    archive_path = File.join(@base_path, 'archive', filename)

    # perform the copy, preserving file attributes
    FileUtils.cp(ingest_path, archive_path, preserve: true)
  end

  def cleanup_file(filename)
    # create ingest path
    ingest_path = File.join(@base_path, 'ingest', filename)
    # remove the file
    FileUtils.remove_file(ingest_path)
  end

end
